@@ -94,6 +94,10 @@ void oaf_activate_async (const char *requirements,
         if (ev->_major != CORBA_NO_EXCEPTION
             || callback_object == CORBA_OBJECT_NIL) {
                 callback (CORBA_OBJECT_NIL, "Could not create CORBA callback", user_data);
+		if (ext_requirements != NULL) {
+                	g_free (ext_requirements);
+		}
+		
                 return;
         }
 
@@ -111,6 +115,10 @@ void oaf_activate_async (const char *requirements,
                                                       oaf_context_get (), ev);
         }
 
+	if (ext_requirements != NULL) {
+		g_free (ext_requirements);
+	}	
+
         if (ev->_major != CORBA_NO_EXCEPTION) {
                 char *message;
                 message = g_strconcat ("Could not contact Activation Context: ", 
